/*
 * livepatch_bsc1196959
 *
 * Fix for CVE-2021-39698, bsc#1196959
 *
 *  Upstream commits:
 *  42288cb44c4b ("wait: add wake_up_pollfree()")
 *  a880b28a71e3 ("binder: use wake_up_pollfree()")
 *  9537bae0da1f ("signalfd: use wake_up_pollfree()"
 *  363bee27e258 ("aio: keep poll requests on waitqueue until completed")
 *  50252e4b5e98 ("aio: fix use-after-free due to missing POLLFREE handling")
 *  791f3465c4af ("io_uring: fix UAF due to missing POLLFREE handling")
 *
 *  SLE12-SP3 commit:
 *  not affected
 *
 *  SLE12-SP4, SLE12-SP5, SLE15 and SLE15-SP1 commit:
 *  not affected
 *
 *  SLE15-SP2 and -SP3 commit:
 *  fbcad1232a2939a59b964cee9145dbaf4fa1e78c
 *  00c1c8d55a7a4fdedb36c7993cb09c9814a4742f
 *  28c3691b228694917e6bcd8822fc16c97c7ffac7
 *  3ae391179ed2a4ee434cfbc4e932906dd8fbe8fa
 *  b026506dc6444c526bb88c0c33100b5843e60d0b
 *
 *
 *  Copyright (c) 2022 SUSE
 *  Author: Nicolai Stange <nstange@suse.de>
 *
 *  Based on the original Linux kernel code. Other copyrights apply.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#include <linux/kernel.h>
#include "livepatch_bsc1196959.h"
#include "bsc1196959_common.h"

int livepatch_bsc1196959_init(void)
{
	int r;

	r = livepatch_bsc1196959_aio_init();
	if (r)
		return r;

	r = livepatch_bsc1196959_io_uring_init();
	if (r)
		return r;

	r = livepatch_bsc1196959_signalfd_init();
	if (r)
		return r;

	return 0;
}
